# Generates all possible CSS selector combinations from an HTML string - Speed up your Selenium automation!
```python
$pip install a-pandas-ex-css-selector-from-html

from a_pandas_ex_css_selector_from_html import pd_add_css_selector_from_html
pd_add_css_selector_from_html()
import pandas as pd

html = "https://pypi.org/project/make-even-odd/0.10/"  # file path, html string, url
df = pd.Q_selector_from_html(html, parser="html.parser", ignore_tags=("html", "body"))

....
952                                ....                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            <input autocapitalize="off" autocomplete="off" class="search-form__search" data-action="keydown@window-&gt;search-focus#focusSearchField" data-controller="search-focus" data-search-focus-target="searchField" id="search" name="q" placeholder="Search projects" spellcheck="false" type="text" value=""/>                                                                                                                                                                                                                                                                     input[placeholder="Search projects"][value=""][autocapitalize="off"][spellcheck="false"]         226            5192
953     <input autocapitalize="off"....                                                                                 input[placeholder="Search projects"][value=""][autocapitalize="off"][data-controller="search-focus"]         226            5187
954     <input autocapitalize="off"....                                                    input[placeholder="Search projects"][value=""][autocapitalize="off"][data-action="keydown@window->search-focus#focusSearchField"]         226            5185
955     <input autocapitalize="off"....                                                                         input[placeholder="Search projects"][value=""][autocapitalize="off"][data-search-focus-target="searchField"]         226            5191
956     <input autocapitalize="off"....                                                                                   input[placeholder="Search projects"][value=""][spellcheck="false"][data-controller="search-focus"]         226            5242
957     <input autocapitalize="off"....                                                      input[placeholder="Search projects"][value=""][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"]         226            5240
958     <input autocapitalize="off"....                                                                           input[placeholder="Search projects"][value=""][spellcheck="false"][data-search-focus-target="searchField"]         226            5246
959     <input autocapitalize="off"....                                          input[placeholder="Search projects"][value=""][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5235
960     <input autocapitalize="off"....                                                               input[placeholder="Search projects"][value=""][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5237
961     <input autocapitalize="off"....                                  input[placeholder="Search projects"][value=""][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5233
962     <input autocapitalize="off"....                                                                                   input[placeholder="Search projects"][autocomplete="off"][autocapitalize="off"][spellcheck="false"]         226            5145
963     <input autocapitalize="off"....                                                                       input[placeholder="Search projects"][autocomplete="off"][autocapitalize="off"][data-controller="search-focus"]         226            5140
964     <input autocapitalize="off"....                                          input[placeholder="Search projects"][autocomplete="off"][autocapitalize="off"][data-action="keydown@window->search-focus#focusSearchField"]         226            5138
965     <input autocapitalize="off"....                                                               input[placeholder="Search projects"][autocomplete="off"][autocapitalize="off"][data-search-focus-target="searchField"]         226            5144
966     <input autocapitalize="off"....                                                                         input[placeholder="Search projects"][autocomplete="off"][spellcheck="false"][data-controller="search-focus"]         226            5163
967     <input autocapitalize="off"....                                            input[placeholder="Search projects"][autocomplete="off"][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"]         226            5161
968     <input autocapitalize="off"....                                                                 input[placeholder="Search projects"][autocomplete="off"][spellcheck="false"][data-search-focus-target="searchField"]         226            5167
969     <input autocapitalize="off"....                                input[placeholder="Search projects"][autocomplete="off"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5156
970     <input autocapitalize="off"....                                                     input[placeholder="Search projects"][autocomplete="off"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5158
971     <input autocapitalize="off"....                        input[placeholder="Search projects"][autocomplete="off"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5154
972     <input autocapitalize="off"....                                                                       input[placeholder="Search projects"][autocapitalize="off"][spellcheck="false"][data-controller="search-focus"]         226            5131
973     <input autocapitalize="off"....                                          input[placeholder="Search projects"][autocapitalize="off"][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"]         226            5129
974     <input autocapitalize="off"....                                                               input[placeholder="Search projects"][autocapitalize="off"][spellcheck="false"][data-search-focus-target="searchField"]         226            5135
975     <input autocapitalize="off"....                              input[placeholder="Search projects"][autocapitalize="off"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5124
976     <input autocapitalize="off"....                                                   input[placeholder="Search projects"][autocapitalize="off"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5126
977     <input autocapitalize="off"....                      input[placeholder="Search projects"][autocapitalize="off"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5122
978     <input autocapitalize="off"....                                input[placeholder="Search projects"][spellcheck="false"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5179
979     <input autocapitalize="off"....                                                     input[placeholder="Search projects"][spellcheck="false"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5181
980     <input autocapitalize="off"....                        input[placeholder="Search projects"][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5177
981     <input autocapitalize="off"....            input[placeholder="Search projects"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5172
982     <input autocapitalize="off"....                                                                                                        input[value=""][autocomplete="off"][autocapitalize="off"][spellcheck="false"]         226            5793
983     <input autocapitalize="off"....                                                                                            input[value=""][autocomplete="off"][autocapitalize="off"][data-controller="search-focus"]         226            5788
984     <input autocapitalize="off"....                                                               input[value=""][autocomplete="off"][autocapitalize="off"][data-action="keydown@window->search-focus#focusSearchField"]         226            5786
985     <input autocapitalize="off"....                                                                                    input[value=""][autocomplete="off"][autocapitalize="off"][data-search-focus-target="searchField"]         226            5792
986     <input autocapitalize="off"....                                                                                              input[value=""][autocomplete="off"][spellcheck="false"][data-controller="search-focus"]         226            5811
987     <input autocapitalize="off"....                                                                 input[value=""][autocomplete="off"][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"]         226            5809
988     <input autocapitalize="off"....                                                                                      input[value=""][autocomplete="off"][spellcheck="false"][data-search-focus-target="searchField"]         226            5815
989     <input autocapitalize="off"....                                                     input[value=""][autocomplete="off"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5804
990     <input autocapitalize="off"....                                                                          input[value=""][autocomplete="off"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5806
991     <input autocapitalize="off"....                                             input[value=""][autocomplete="off"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5802
992     <input autocapitalize="off"....                                                                                            input[value=""][autocapitalize="off"][spellcheck="false"][data-controller="search-focus"]         226            5779
993     <input autocapitalize="off"....                                                               input[value=""][autocapitalize="off"][spellcheck="false"][data-action="keydown@window->search-focus#focusSearchField"]         226            5777
994     <input autocapitalize="off"....                                                                                    input[value=""][autocapitalize="off"][spellcheck="false"][data-search-focus-target="searchField"]         226            5783
995     <input autocapitalize="off"....                                                   input[value=""][autocapitalize="off"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5772
996     <input autocapitalize="off"....                                                                        input[value=""][autocapitalize="off"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5774
997     <input autocapitalize="off"....                                           input[value=""][autocapitalize="off"][data-action="keydown@window->search-focus#focusSearchField"][data-search-focus-target="searchField"]         226            5770
998     <input autocapitalize="off"....                                                     input[value=""][spellcheck="false"][data-controller="search-focus"][data-action="keydown@window->search-focus#focusSearchField"]         226            5827
999     <input autocapitalize="off"....                                                                          input[value=""][spellcheck="false"][data-controller="search-focus"][data-search-focus-target="searchField"]         226            5829
....